==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/tao/ImR_Client/ServerObject_i.h <==
//=============================================================================
/**
 *  @file    ServerObject_i.h
 *
 *  ServerObject_i.h,v 1.3 2005/07/04 09:26:53 jwillemsen Exp
 *
 *  @author  Darrell Brunsch and Irfan Pyarali
 */
// ===================================================================

#ifndef TAO_IMPLREPO_I_H
#define TAO_IMPLREPO_I_H

#include /**/ "ace/pre.h"

#include "tao/ORB.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "tao/ImR_Client/ServerObjectS.h"
#include "tao/ImR_Client/imr_client_export.h"

/**
 * @class ServerObject_i
 *
 * @brief Class for pinging a server.  Implementation Repository uses
 * this to communicate with the IMR registered servers.
 *
 * \nosubgrouping
 *
 **/
class TAO_IMR_Client_Export ServerObject_i
  : public POA_ImplementationRepository::ServerObject
{
public:
  /// Constructor.
  ServerObject_i (CORBA::ORB_ptr orb,
                  PortableServer::POA_ptr poa);

  /// Ping method.
  void ping (ACE_ENV_SINGLE_ARG_DECL)
    ACE_THROW_SPEC ((CORBA::SystemException));

  /// Shutdown the server.
  void shutdown (ACE_ENV_SINGLE_ARG_DECL)
    ACE_THROW_SPEC ((CORBA::SystemException));

  /// Returns the default POA for this servant.
  PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL);

protected:
  /// Our ORB.  We need this member in case we need to shutdown the
  /// server.
  CORBA::ORB_var orb_;

  /// POA that we are registered with.
  PortableServer::POA_var poa_;
};

#include /**/ "ace/post.h"

#endif /* TAO_IMPLREPO_I_H */

==> ace_5.7.7+dfsg.orig.tar.gz: ACE_wrappers/TAO/tao/ImR_Client/ServerObject_i.h <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file    ServerObject_i.h
 *
 *  $Id: ServerObject_i.h 76995 2007-02-11 12:51:42Z johnnyw $
 *
 *  @author  Darrell Brunsch
 *  @author  Irfan Pyarali
 */
// ===================================================================

#ifndef TAO_SERVEROBJECT_I_H
#define TAO_SERVEROBJECT_I_H

#include /**/ "ace/pre.h"

#include "tao/ORB.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "tao/ImR_Client/ServerObjectS.h"
#include "tao/ImR_Client/imr_client_export.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

/**
 * @class ServerObject_i
 *
 * @brief Class for pinging a server.  Implementation Repository uses
 * this to communicate with the IMR registered servers.
 *
 * \nosubgrouping
 *
 **/
class TAO_IMR_Client_Export ServerObject_i
  : public POA_ImplementationRepository::ServerObject
{
public:
  /// Constructor.
  ServerObject_i (CORBA::ORB_ptr orb, PortableServer::POA_ptr poa);

  /// Ping method.
  void ping (void);

  /// Shutdown the server.
  void shutdown (void);

  /// Returns the default POA for this servant.
  PortableServer::POA_ptr _default_POA (void);

protected:
  /// Our ORB.  We need this member in case we need to shutdown the
  /// server.
  CORBA::ORB_var orb_;

  /// POA that we are registered with.
  PortableServer::POA_var poa_;
};

TAO_END_VERSIONED_NAMESPACE_DECL

#include /**/ "ace/post.h"

#endif /* TAO_SERVEROBJECT_I_H */
